@@ -14,8 +14,7 @@
 #include <cstdlib>
 
 Arena::Arena()
-{
-}
+= default;
 
 Arena::~Arena()
 {
@@ -83,7 +82,7 @@ void Arena::addPlayerPosition(const QPointF &p_position)
     int nShuffle;
     for (int i = 0; i < m_playerPosition.size(); i++)
     {
-        nShuffle = granatier::RNG::fromRange(0, m_playerPosition.size()-1);
+        nShuffle = granatier::RNG::fromRange<int>(0, m_playerPosition.size()-1);
         m_playerPosition.swapItemsAt(i, nShuffle);
     }
 }
@@ -114,11 +113,11 @@ QPoint Arena::getCoords(Cell* p_cell) const
         {
             if (&m_cells[i][j] == p_cell)
             {
-                return QPoint(j, i);
+                return {j, i};
             }
         }
     }
-    return QPoint();
+    return {};
 }
 
 int Arena::getRowFromY(const qreal p_y) const
